import re

def my_function(arg1: int, arg2: str) -> bool:
    """Example function with types documented in the docstring.

    `PEP 484`_ type annotations are supported. If attribute, parameter, and
    return types are annotated according to `PEP 484`_, they do not need to be
    included in the docstring:

    Args:
        arg1 (int): The first parameter.
        arg2 (str): The second parameter.

    Returns:
        bool: The return value. True for success, False otherwise.

    .. _PEP 484:
        https://www.python.org/dev/peps/pep-0484/

    """
    pass

docstring = my_function.__doc__
match = re.search(r"Args:\n(.*?)(?:\n\n|$)", docstring, re.DOTALL)
if match:
    args_section = match.group(1)
    args = re.findall(r"\s*(\w+) \(([^)]+)\): (.*)", args_section)
    for name, type_, description in args:
        print(f"Name: {name}, Type: {type_}, Description: {description}")



import inspect


class PyProcess:
    def __init__(self, func=None, parameter_id=None):
        self.func = func
        self.parameter_id = parameter_id

    def __call__(self):
        print(f"Load parameter set {self.parameter_id}")

        sig = inspect.signature(self.func)
        func_params = sig.parameters

        # get all the parameters from the parameter dictionary
        parameters = {}

        for name, param in func_params.items():
            print(f"Name: {name}, Kind: {param.kind}, Default: {param.default}")

            parameters[name] = param.default

        result = self.func(**parameters)

        # write the result to the db
        return result


def process(process: type(callable), parameter_set: int = 0):
    data = {}

    print(f"Running {process.func.__name__}")

    process.parameter_id = parameter_set
    data["result"] = process()

    return data



import pyprexor.core as core


def test_process():
    @core.PyProcess
    def simple(number_1: int = 1, number_2: int = 2):
        return number_1 + number_2

    assert core.process(simple, 10) == {"result": 3}
